Changelog
=========

0.1.6 (2022-01-12)
------------------
* Added support for Django 3.2 and 4.0.
* Dropped Python 2 support.

0.1.5 (2020-04-14)
------------------
* Added support for Python 3.8 and Django 3.0

0.1.4 (2019-10-19)
------------------
* Added query property to delayed querysets.
* Fixed bug with count() and select_related() in MySQL
* Added tests for Django 3.0

0.1.3 (2019-04-24)
------------------
* Added tests for Django 2.2

0.1.2 (2018-12-14)
------------------
* Added support for nested unions and intersections

0.1.1 (2018-07-16)
------------------

* Cached the queryset generated after applying the delayed operation.

0.1.0 (2018-03-14)
------------------

* First release on PyPI.
